summaryrefslogtreecommitdiffstats
path: root/wp-includes/rest-api/endpoints/class-wp-rest-template-revisions-controller.php
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:51:18 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:51:18 +0000
commit0e41b5d52fdc6af6442816b5f465c9db9f84e126 (patch)
treee139a90049b158d4eed892d1662ee7f5c358fa31 /wp-includes/rest-api/endpoints/class-wp-rest-template-revisions-controller.php
parentAdding upstream version 6.5.5+dfsg1. (diff)
downloadwordpress-upstream.tar.xz
wordpress-upstream.zip
Adding upstream version 6.6.1+dfsg1.upstream/6.6.1+dfsg1upstream
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to '')
-rw-r--r--wp-includes/rest-api/endpoints/class-wp-rest-template-revisions-controller.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/wp-includes/rest-api/endpoints/class-wp-rest-template-revisions-controller.php b/wp-includes/rest-api/endpoints/class-wp-rest-template-revisions-controller.php
index 8d32ecb..22cdc26 100644
--- a/wp-includes/rest-api/endpoints/class-wp-rest-template-revisions-controller.php
+++ b/wp-includes/rest-api/endpoints/class-wp-rest-template-revisions-controller.php
@@ -156,15 +156,15 @@ class WP_REST_Template_Revisions_Controller extends WP_REST_Revisions_Controller
}
/**
- * Gets the parent post, if the ID is valid.
+ * Gets the parent post, if the template ID is valid.
*
* @since 6.4.0
*
* @param int $parent_post_id Supplied ID.
* @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
*/
- protected function get_parent( $parent_post_id ) {
- $template = get_block_template( $parent_post_id, $this->parent_post_type );
+ protected function get_parent( $parent_template_id ) {
+ $template = get_block_template( $parent_template_id, $this->parent_post_type );
if ( ! $template ) {
return new WP_Error(
@@ -156,15 +156,15 @@ class WP_REST_Template_Revisions_Controller extends WP_REST_Revisions_Controller
* @since 6.4.0
*
- * @param int $parent_post_id Supplied ID.
+ * @param string $parent_template_id Supplied ID.
* @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
*/